@@ -257,10 +257,10 @@ def slice_play(footage_play_dir, full_footage_file, gobj, play,
     duration = '%02d:%02d:%02d.%d' % (dr.hh, dr.mm, dr.ss, dr.milli)
     cmd = ['ffmpeg',
            '-ss', start_time,
-           '-i', full_footage_file,
            '-t', duration,
-           '-map', '0',
-           '-strict', '-2',
+           '-i', full_footage_file,
+           '-acodec', 'copy',
+           '-vcodec', 'copy',
            outpath,
            ]
     _run_command(cmd)
@@ -301,7 +301,11 @@ def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
            '-i', url]
     if dry_run:
         cmd += ['-t', '30']
-    cmd += ['-strict', '-2', fp]
+    cmd += ['-absf', 'aac_adtstoasc',  # no idea. ffmpeg says I need it though.
+            '-acodec', 'copy',
+            '-vcodec', 'copy',
+            fp,
+            ]
 
     _eprint('Downloading game %s %s' % (gobj.eid, _nice_game(gobj)))
     if not _run_command(cmd):
@@ -406,8 +410,8 @@ def plays(gobj, coach=True):
     __broadcast_cache[gobj.eid] = ps
 
     # Save the XML data to disk if the game is over.
-    if gobj.game_over():
-        fp = _xmlf % (gobj.eid, gobj.gamekey)
+    fp = _xmlf % (gobj.eid, gobj.gamekey)
+    if gobj.game_over() and not os.access(fp, os.R_OK):
         try:
             print >> gzip.open(fp, 'w+'), rawxml,
         except IOError:
